@@ -62,7 +62,7 @@ class Witter():
         self.program = hildon.Program()
         self.program.__init__()
 
-
+        self.textcolour="#000000"
         # set name of application: this shows in titlebar
         gtk.set_application_name("Witter")
         #Set the Glade file
@@ -840,11 +840,13 @@ class Witter():
                 print "found n900"
                 self.tweetcolour= "#FFFFFF"
                 self.namecolour="#FE00B8"
+                self.textcolour="#FFFFFF"
                 self.defaultwidth=560
                 self.maemo_ver=5
             else:
                 print "found"+ read_data
                 self.maemo_ver=4
+                self.textcolour="#000000"
         except IOError:
             #couldn't find the file 
             print "Assuming pre-maemo5"
